@@ -23,11 +23,11 @@ from adjustText import adjust_text
 from itertools import cycle
 
 #import Code.C_colors as CC
-from . import plot_objects as PO
-from .wheels import linewidthwheel, parawheel, colorwheel
-from .plot_map import get_bounding_box, PlotMap
-from .color_schema import Comp_Style
-from .cursor import PlotCursor
+from .packages import plot_objects  as PO
+from .packages.wheels import linewidthwheel, parawheel, colorwheel
+from .packages.plot_map import get_bounding_box, PlotMap
+from .packages.color_schema import Comp_Style
+from .packages.cursor import PlotCursor
 
 
 def PlotPoints(
@@ -245,7 +245,7 @@ def PlotLines(
                 )
 
             else:                           
-                Color_list=["k","b","g","r","c","m","y"]                
+                Color_list=["k","b","g","r","c","m","y","gold","magenta","lawngreen","aquamarine"]                
                 l = lines.Line2D(
                     x,
                     y,
@@ -348,6 +348,7 @@ def SaveFig(fname, dpi=600):
 def quickplot(
     Netz,
     Info="",
+    FigSize=(12.5,8.5),
     Names=False,
     alpha=1,
     SingleColor="",
@@ -386,7 +387,7 @@ def quickplot(
     parameter="",
     randomlinecolors=False,
     thicklines=False,
-    TM_Borders_filename='../TM_World_Borders/TM_WORLD_BORDERS-0.3.shp',
+    TM_Borders_filename=None,
     dictionary="param",):
     """
     Creates Plot of Netz-Class object
@@ -425,6 +426,7 @@ def quickplot(
     Style Parameters
     ----------------
     MapColor            boolean, background map in color (True) or in blackwhite (False) [default: True]
+    FigSize             (x,y)=(float,float); [default: (12.5,8.5)
     figureNum           int, number of the figure [default: 1]
     SupTitleStr         str, of title of plot [default: '']
     LegendStyle         'Str' or 'Str(Num)', only Names ->'Str'; Names with count-> 'Str(Num)' [default: 'Str']
@@ -471,7 +473,9 @@ def quickplot(
         Fig = [fig, ax] = PlotMap(
             countrycode=countrycode,
             figureNum=figureNum,
+            FigSize=FigSize,
             MapColor=MapColor,
+            Axis=Axis,
             SupTitleStr=SupTitleStr,
             MapAlpha=MapAlpha,
             BackGroundAlpha=BackGroundAlpha,
@@ -507,7 +511,7 @@ def quickplot(
     colors = cycle(["b", "g", "r", "m", "c", "y", "k"])
     markers = cycle(["o", "x", "+", "P", "D", "s", "^"])
 
-    size_default = 18
+    size_default = 25#18
     line_size_default = 1
     linestyle = SingleLineStyle
     if SingleSize != "":
